@@ -19,14 +19,18 @@ package org.gradle.api.plugins.quality.internal;
 import org.gradle.api.Task;
 import org.gradle.api.plugins.quality.CheckstyleReports;
 import org.gradle.api.reporting.SingleFileReport;
+import org.gradle.api.reporting.internal.CustomizableHtmlReportImpl;
 import org.gradle.api.reporting.internal.TaskGeneratedSingleFileReport;
 import org.gradle.api.reporting.internal.TaskReportContainer;
 
+import javax.inject.Inject;
+
 public class CheckstyleReportsImpl extends TaskReportContainer<SingleFileReport> implements CheckstyleReports {
+    @Inject
     public CheckstyleReportsImpl(Task task) {
         super(SingleFileReport.class, task);
 
-        add(TaskGeneratedSingleFileReport.class, "html", task);
+        add(CustomizableHtmlReportImpl.class, "html", task);
         add(TaskGeneratedSingleFileReport.class, "xml", task);
     }
 
