@@ -944,8 +944,10 @@ public interface Project extends Comparable<Project>, ExtensionAware, PluginAwar
      * @throws org.gradle.api.InvalidUserDataException If the provided class is null.
      * @see org.gradle.api.provider.ProviderFactory#property(Class)
      * @since 4.0
+     * @deprecated Use {@link ObjectFactory#property(Class)} instead.
      */
     @Incubating
+    @Deprecated
     <T> PropertyState<T> property(Class<T> clazz);
 
     /**
