@@ -16,30 +16,28 @@
 
 package org.gradle.api.internal.file.collections;
 
+import com.google.common.base.Charsets;
 import org.gradle.api.JavaVersion;
-import org.gradle.internal.Cast;
+import org.gradle.api.internal.file.collections.jdk7.Jdk7DirectoryWalker;
 import org.gradle.internal.Factory;
-import org.gradle.internal.UncheckedException;
 import org.gradle.internal.nativeintegration.services.FileSystems;
 import org.gradle.internal.nativeplatform.filesystem.FileSystem;
-import org.gradle.internal.reflect.DirectInstantiator;
-import org.gradle.internal.resource.CharsetUtil;
 
 import java.nio.charset.Charset;
 
 public class DefaultDirectoryWalkerFactory implements Factory<DirectoryWalker> {
-    private final ClassLoader classLoader;
     private final JavaVersion javaVersion;
+    private final FileSystem fileSystem;
     private DirectoryWalker instance;
 
-    DefaultDirectoryWalkerFactory(ClassLoader classLoader, JavaVersion javaVersion) {
+    public DefaultDirectoryWalkerFactory(JavaVersion javaVersion, FileSystem fileSystem) {
         this.javaVersion = javaVersion;
-        this.classLoader = classLoader;
+        this.fileSystem = fileSystem;
         reset();
     }
 
     DefaultDirectoryWalkerFactory() {
-        this(DefaultDirectoryWalkerFactory.class.getClassLoader(), JavaVersion.current());
+        this(JavaVersion.current(), FileSystems.getDefault());
     }
 
     public DirectoryWalker create() {
@@ -51,14 +49,8 @@ public class DefaultDirectoryWalkerFactory implements Factory<DirectoryWalker> {
     }
 
     private DirectoryWalker createInstance() {
-        FileSystem fileSystem = FileSystems.getDefault();
         if (javaVersion.isJava8Compatible() || (javaVersion.isJava7Compatible() && defaultEncodingContainsPlatformEncoding())) {
-            try {
-                Class clazz = classLoader.loadClass("org.gradle.api.internal.file.collections.jdk7.Jdk7DirectoryWalker");
-                return Cast.uncheckedCast(DirectInstantiator.instantiate(clazz, fileSystem));
-            } catch (ClassNotFoundException e) {
-                throw UncheckedException.throwAsUncheckedException(e);
-            }
+            return new Jdk7DirectoryWalker(fileSystem);
         } else {
             return new DefaultDirectoryWalker(fileSystem);
         }
@@ -70,7 +62,7 @@ public class DefaultDirectoryWalkerFactory implements Factory<DirectoryWalker> {
         String platformEncoding = System.getProperty("sun.jnu.encoding");
         Charset platformCharset = platformEncoding != null && Charset.isSupported(platformEncoding) ? Charset.forName(platformEncoding) : null;
         // fallback to require UTF-8 when platformCharset cannot be resolved
-        Charset requiredCharset = platformCharset != null ? platformCharset : CharsetUtil.UTF_8;
+        Charset requiredCharset = platformCharset != null ? platformCharset : Charsets.UTF_8;
         return Charset.defaultCharset().contains(requiredCharset);
     }
 }
