@@ -18,17 +18,20 @@ package org.gradle.api.internal.artifacts;
 
 import org.gradle.api.artifacts.ModuleVersionIdentifier;
 import org.gradle.api.artifacts.ModuleVersionSelector;
+import org.gradle.api.artifacts.VersionConstraint;
+import org.gradle.api.artifacts.component.ModuleComponentSelector;
+import org.gradle.api.internal.artifacts.dependencies.DefaultMutableVersionConstraint;
 
 public class DefaultModuleVersionSelector implements ModuleVersionSelector {
 
     private String group;
     private String name;
-    private String version;
+    private VersionConstraint moduleVersionConstraint;
 
-    public DefaultModuleVersionSelector(String group, String name, String version) {
+    private DefaultModuleVersionSelector(String group, String name, VersionConstraint versionConstraint) {
         this.group = group;
         this.name = name;
-        this.version = version;
+        this.moduleVersionConstraint = versionConstraint;
     }
 
     public String getGroup() {
@@ -50,21 +53,21 @@ public class DefaultModuleVersionSelector implements ModuleVersionSelector {
     }
 
     public String getVersion() {
-        return version;
+        return moduleVersionConstraint.getPreferredVersion();
+    }
+
+    @Override
+    public VersionConstraint getVersionConstraint() {
+        return moduleVersionConstraint;
     }
 
     public boolean matchesStrictly(ModuleVersionIdentifier identifier) {
         return new ModuleVersionSelectorStrictSpec(this).isSatisfiedBy(identifier);
     }
 
-    public DefaultModuleVersionSelector setVersion(String version) {
-        this.version = version;
-        return this;
-    }
-
     @Override
     public String toString() {
-        return String.format("%s:%s:%s", group, name, version);
+        return String.format("%s:%s:%s", group, name, moduleVersionConstraint.getPreferredVersion());
     }
 
     @Override
@@ -84,7 +87,7 @@ public class DefaultModuleVersionSelector implements ModuleVersionSelector {
         if (name != null ? !name.equals(that.name) : that.name != null) {
             return false;
         }
-        if (version != null ? !version.equals(that.version) : that.version != null) {
+        if (moduleVersionConstraint != null ? !moduleVersionConstraint.equals(that.moduleVersionConstraint) : that.moduleVersionConstraint != null) {
             return false;
         }
 
@@ -95,11 +98,19 @@ public class DefaultModuleVersionSelector implements ModuleVersionSelector {
     public int hashCode() {
         int result = group != null ? group.hashCode() : 0;
         result = 31 * result + (name != null ? name.hashCode() : 0);
-        result = 31 * result + (version != null ? version.hashCode() : 0);
+        result = 31 * result + moduleVersionConstraint.hashCode();
         return result;
     }
 
-    public static ModuleVersionSelector newSelector(String group, String name, String version) {
+    public static ModuleVersionSelector newSelector(String group, String name, String preferredVersion) {
+        return new DefaultModuleVersionSelector(group, name, new DefaultMutableVersionConstraint(preferredVersion));
+    }
+
+    public static ModuleVersionSelector newSelector(String group, String name, VersionConstraint version) {
         return new DefaultModuleVersionSelector(group, name, version);
     }
+
+    public static ModuleVersionSelector newSelector(ModuleComponentSelector selector) {
+        return new DefaultModuleVersionSelector(selector.getGroup(), selector.getModule(), selector.getVersionConstraint());
+    }
 }
