@@ -24,19 +24,20 @@ import org.gradle.api.artifacts.PublishArtifact;
 import org.gradle.api.artifacts.PublishArtifactSet;
 import org.gradle.api.attributes.AttributeContainer;
 import org.gradle.api.internal.DefaultDomainObjectSet;
+import org.gradle.api.internal.artifacts.ConfigurationVariantInternal;
 import org.gradle.api.internal.artifacts.DefaultPublishArtifactSet;
 import org.gradle.api.internal.attributes.AttributeContainerInternal;
-import org.gradle.api.internal.attributes.DefaultMutableAttributeContainer;
+import org.gradle.api.internal.attributes.ImmutableAttributeContainerWithErrorMessage;
 import org.gradle.api.internal.attributes.ImmutableAttributesFactory;
 import org.gradle.api.internal.file.FileCollectionFactory;
-import org.gradle.internal.DisplayName;
 import org.gradle.internal.Describables;
+import org.gradle.internal.DisplayName;
 import org.gradle.internal.typeconversion.NotationParser;
 
-public class DefaultVariant implements ConfigurationVariant {
+public class DefaultVariant implements ConfigurationVariantInternal {
     private final Describable parentDisplayName;
     private final String name;
-    private final AttributeContainerInternal attributes;
+    private AttributeContainerInternal attributes;
     private final NotationParser<Object, ConfigurablePublishArtifact> artifactNotationParser;
     private final PublishArtifactSet artifacts;
 
@@ -47,7 +48,7 @@ public class DefaultVariant implements ConfigurationVariant {
                           ImmutableAttributesFactory cache) {
         this.parentDisplayName = parentDisplayName;
         this.name = name;
-        attributes = new DefaultMutableAttributeContainer(cache, parentAttributes);
+        attributes = cache.mutable(parentAttributes);
         this.artifactNotationParser = artifactNotationParser;
         artifacts = new DefaultPublishArtifactSet(getAsDescribable(), new DefaultDomainObjectSet<PublishArtifact>(PublishArtifact.class), fileCollectionFactory);
     }
@@ -92,4 +93,14 @@ public class DefaultVariant implements ConfigurationVariant {
         artifacts.add(publishArtifact);
         configureAction.execute(publishArtifact);
     }
+
+    @Override
+    public String toString() {
+        return getAsDescribable().getDisplayName();
+    }
+
+    @Override
+    public void preventFurtherMutation() {
+        attributes = new ImmutableAttributeContainerWithErrorMessage(attributes.asImmutable(), parentDisplayName);
+    }
 }
