@@ -17,12 +17,11 @@
 package org.gradle.internal.resource.cached;
 
 import org.gradle.api.internal.artifacts.ivyservice.CacheLockingManager;
+import org.gradle.internal.serialize.BaseSerializerFactory;
 import org.gradle.util.BuildCommencedTimeProvider;
 
 public class ByUrlCachedExternalResourceIndex extends DefaultCachedExternalResourceIndex<String> {
-
     public ByUrlCachedExternalResourceIndex(String persistentCacheFile, BuildCommencedTimeProvider timeProvider, CacheLockingManager cacheLockingManager) {
-        super(persistentCacheFile, String.class, timeProvider, cacheLockingManager);
+        super(persistentCacheFile, BaseSerializerFactory.STRING_SERIALIZER, timeProvider, cacheLockingManager);
     }
-
 }
