@@ -15,6 +15,7 @@
  */
 package org.gradle.plugins.ide.api;
 
+import org.gradle.api.tasks.Internal;
 import org.gradle.internal.xml.XmlTransformer;
 import org.gradle.plugins.ide.internal.generator.generator.PersistableConfigurationObject;
 import org.gradle.plugins.ide.internal.generator.generator.PersistableConfigurationObjectGenerator;
@@ -41,7 +42,8 @@ public abstract class XmlGeneratorTask<T extends PersistableConfigurationObject>
         };
     }
 
-    protected XmlTransformer getXmlTransformer() {
+    @Internal
+    public XmlTransformer getXmlTransformer() {
         return xmlTransformer;
     }
 
