@@ -31,11 +31,6 @@ public class AccessRule {
         this.pattern = Preconditions.checkNotNull(pattern);
     }
 
-    @Deprecated
-    public AccessRule(Object kind, Object pattern) {
-        this((String)kind, (String)pattern);
-    }
-
     public String getKind() {
         return kind;
     }
