@@ -18,15 +18,12 @@ package org.gradle.plugins.ide.eclipse.model;
 
 import com.google.common.base.Preconditions;
 import groovy.util.Node;
-import org.gradle.util.DeprecationLogger;
 
 /**
  * A classpath entry representing a project dependency.
  */
 public class ProjectDependency extends AbstractClasspathEntry {
 
-    private String gradlePath;
-
     public ProjectDependency(Node node) {
         super(node);
         assertPathIsValid();
@@ -41,29 +38,6 @@ public class ProjectDependency extends AbstractClasspathEntry {
         assertPathIsValid();
     }
 
-    /**
-     * Create a dependency on another Eclipse project.
-     * @deprecated Use {@link #ProjectDependency(String)} instead
-     */
-    @Deprecated
-    public ProjectDependency(String path, String gradlePath) {
-        this(path);
-        DeprecationLogger.nagUserOfDiscontinuedMethod("ProjectDependency(String path, String gradlePath)", "Please use ProjectDependency(String path) instead.");
-        this.gradlePath = gradlePath;
-    }
-
-    @Deprecated
-    public String getGradlePath() {
-        DeprecationLogger.nagUserOfDiscontinuedMethod("ProjectDependency.getGradlePath()");
-        return gradlePath;
-    }
-
-    @Deprecated
-    public void setGradlePath(String gradlePath) {
-        DeprecationLogger.nagUserOfDiscontinuedMethod("ProjectDependency.setGradlePath(String)");
-        this.gradlePath = gradlePath;
-    }
-
     private void assertPathIsValid() {
         Preconditions.checkArgument(path.startsWith("/"));
     }
