@@ -20,15 +20,15 @@ import org.gradle.api.Action;
 
 import java.io.File;
 import java.util.Collections;
-import java.util.Map;
+import java.util.LinkedHashMap;
 import java.util.Set;
 
 public class JarClasspathSnapshot {
 
-    private final Map<File, JarSnapshot> jarSnapshots;
+    private final LinkedHashMap<File, JarSnapshot> jarSnapshots;
     private final JarClasspathSnapshotData data;
 
-    public JarClasspathSnapshot(Map<File, JarSnapshot> jarSnapshots, JarClasspathSnapshotData data) {
+    public JarClasspathSnapshot(LinkedHashMap<File, JarSnapshot> jarSnapshots, JarClasspathSnapshotData data) {
         this.jarSnapshots = jarSnapshots;
         this.data = data;
     }
@@ -37,6 +37,14 @@ public class JarClasspathSnapshot {
         return jarSnapshots.get(jarArchive.file);
     }
 
+    public JarSnapshot getSnapshot(File file) {
+        return jarSnapshots.get(file);
+    }
+
+    public Set<File> getJars() {
+        return jarSnapshots.keySet();
+    }
+
     public boolean isAnyClassDuplicated(Set<String> classNames) {
         boolean noCommonElements = Collections.disjoint(data.getDuplicateClasses(), classNames);
         return !noCommonElements;
