@@ -16,11 +16,11 @@
 
 package org.gradle.language.java.internal;
 
-import org.gradle.api.internal.cache.FileContentCacheFactory;
 import org.gradle.api.internal.component.ArtifactType;
 import org.gradle.api.internal.component.ComponentTypeRegistry;
 import org.gradle.api.internal.file.FileCollectionFactory;
 import org.gradle.api.internal.tasks.compile.AnnotationProcessorDetector;
+import org.gradle.cache.internal.FileContentCacheFactory;
 import org.gradle.internal.service.ServiceRegistration;
 import org.gradle.internal.service.scopes.AbstractPluginServiceRegistry;
 import org.gradle.jvm.JvmLibrary;
