@@ -19,8 +19,11 @@ package org.gradle.language.swift.internal;
 import org.gradle.language.nativeplatform.internal.AbstractNativeCompileSpec;
 import org.gradle.nativeplatform.toolchain.internal.compilespec.SwiftCompileSpec;
 
+import java.io.File;
+
 public class DefaultSwiftCompileSpec extends AbstractNativeCompileSpec implements SwiftCompileSpec {
     private String moduleName;
+    private File moduleFile;
 
     @Override
     public String getModuleName() {
@@ -31,4 +34,14 @@ public class DefaultSwiftCompileSpec extends AbstractNativeCompileSpec implement
     public void setModuleName(String moduleName) {
         this.moduleName = moduleName;
     }
+
+    @Override
+    public File getModuleFile() {
+        return moduleFile;
+    }
+
+    @Override
+    public void setModuleFile(File moduleFile) {
+        this.moduleFile = moduleFile;
+    }
 }
