@@ -18,6 +18,7 @@ package org.gradle.api.tasks.scala;
 
 import org.gradle.api.Incubating;
 import org.gradle.api.tasks.Internal;
+import org.gradle.api.tasks.LocalState;
 
 import java.io.File;
 import java.io.Serializable;
@@ -34,10 +35,8 @@ public class IncrementalCompileOptions implements Serializable {
 
     /**
      * Returns the file path where results of code analysis are to be stored.
-     *
-     * @return the file path where which results of code analysis are to be stored
      */
-    @Internal
+    @LocalState
     public File getAnalysisFile() {
         return analysisFile;
     }
@@ -52,9 +51,6 @@ public class IncrementalCompileOptions implements Serializable {
     /**
      * Returns the directory or archive path by which the code produced by this task
      * is published to other {@code ScalaCompile} tasks.
-     *
-     * @return the directory or archive path by which the code produced by this task
-     * is published to other {@code ScalaCompile} tasks
      */
     // only an input for other task instances
     @Internal
