@@ -16,10 +16,12 @@
 
 package org.gradle.language.scala.toolchain;
 
+import org.gradle.api.Incubating;
 import org.gradle.platform.base.ToolChain;
 
 /**
  * A set of tools for building Scala applications
  */
+@Incubating
 public interface ScalaToolChain extends ToolChain {
 }
