@@ -26,8 +26,6 @@ public interface LogHeaderFormatter {
     /**
      * Given a message, return possibly-styled output for displaying message meant to categorize
      * other messages "below" it, if any.
-     *
-     * @since 4.0
      */
-    List<StyledTextOutputEvent.Span> format(String logHeader, String description, String shortDescription, String status);
+    List<StyledTextOutputEvent.Span> format(String logHeader, String description, String shortDescription, String status, boolean failed);
 }
