@@ -16,6 +16,7 @@
 package org.gradle.api.artifacts.maven;
 
 import groovy.lang.Closure;
+import groovy.lang.GroovyObject;
 import org.gradle.api.Action;
 import org.gradle.api.XmlProvider;
 import org.gradle.api.artifacts.ConfigurationContainer;
@@ -57,6 +58,29 @@ public interface MavenPom {
      */
     MavenPom project(Closure pom);
 
+    /**
+     * Provides a builder for the Maven POM for adding or modifying properties of the Maven {@link #getModel()}.
+     * The syntax is exactly the same as used by polyglot Maven. For example:
+     *
+     * <pre>
+     * pom.project {
+     *    inceptionYear '2008'
+     *    licenses {
+     *       license {
+     *          name 'The Apache Software License, Version 2.0'
+     *          url 'http://www.apache.org/licenses/LICENSE-2.0.txt'
+     *          distribution 'repo'
+     *       }
+     *    }
+     * }
+     * </pre>
+     *
+     * @return this
+     *
+     * @since 4.2
+     */
+    MavenPom project(Action<? super GroovyObject> pom);
+
     /**
      * Returns the group id for this POM.
      *
