@@ -27,8 +27,8 @@ import org.gradle.api.artifacts.dsl.RepositoryHandler;
 import org.gradle.api.artifacts.maven.Conf2ScopeMappingContainer;
 import org.gradle.api.artifacts.maven.MavenPom;
 import org.gradle.api.artifacts.maven.MavenResolver;
-import org.gradle.api.internal.artifacts.DefaultModuleVersionIdentifier;
-import org.gradle.api.internal.artifacts.ModuleInternal;
+import org.gradle.api.internal.artifacts.ImmutableModuleIdentifierFactory;
+import org.gradle.api.internal.artifacts.Module;
 import org.gradle.api.internal.artifacts.configurations.ConfigurationInternal;
 import org.gradle.api.internal.artifacts.dsl.DefaultRepositoryHandler;
 import org.gradle.api.internal.artifacts.ivyservice.projectmodule.DefaultProjectPublication;
@@ -69,19 +69,22 @@ public class MavenPlugin implements Plugin<ProjectInternal> {
     private final ProjectConfigurationActionContainer configurationActionContainer;
     private final MavenSettingsProvider mavenSettingsProvider;
     private final LocalMavenRepositoryLocator mavenRepositoryLocator;
+    private final ImmutableModuleIdentifierFactory moduleIdentifierFactory;
 
     private Project project;
 
     @Inject
     public MavenPlugin(Factory<LoggingManagerInternal> loggingManagerFactory, FileResolver fileResolver,
                        ProjectPublicationRegistry publicationRegistry, ProjectConfigurationActionContainer configurationActionContainer,
-                       MavenSettingsProvider mavenSettingsProvider, LocalMavenRepositoryLocator mavenRepositoryLocator) {
+                       MavenSettingsProvider mavenSettingsProvider, LocalMavenRepositoryLocator mavenRepositoryLocator,
+                       ImmutableModuleIdentifierFactory moduleIdentifierFactory) {
         this.loggingManagerFactory = loggingManagerFactory;
         this.fileResolver = fileResolver;
         this.publicationRegistry = publicationRegistry;
         this.configurationActionContainer = configurationActionContainer;
         this.mavenSettingsProvider = mavenSettingsProvider;
         this.mavenRepositoryLocator = mavenRepositoryLocator;
+        this.moduleIdentifierFactory = moduleIdentifierFactory;
     }
 
     public void apply(final ProjectInternal project) {
@@ -115,6 +118,12 @@ public class MavenPlugin implements Plugin<ProjectInternal> {
                 configureWarScopeMappings(project.getConfigurations(), pluginConvention.getConf2ScopeMappings());
             }
         });
+        plugins.withType(JavaLibraryPlugin.class, new Action<JavaLibraryPlugin>() {
+            @Override
+            public void execute(JavaLibraryPlugin javaLibraryPlugin) {
+                configureJavaLibraryScopeMappings(project.getConfigurations(), pluginConvention.getConf2ScopeMappings());
+            }
+        });
     }
 
     private void configureUploadTasks(final DefaultDeployerFactory deployerFactory) {
@@ -137,10 +146,10 @@ public class MavenPlugin implements Plugin<ProjectInternal> {
                 }
 
                 ConfigurationInternal configuration = (ConfigurationInternal) uploadArchives.getConfiguration();
-                ModuleInternal module = configuration.getModule();
+                Module module = configuration.getModule();
                 for (MavenResolver resolver : uploadArchives.getRepositories().withType(MavenResolver.class)) {
                     MavenPom pom = resolver.getPom();
-                    ModuleVersionIdentifier publicationId = new DefaultModuleVersionIdentifier(
+                    ModuleVersionIdentifier publicationId = moduleIdentifierFactory.moduleWithVersion(
                             pom.getGroupId().equals(MavenProject.EMPTY_PROJECT_GROUP_ID) ? module.getGroup() : pom.getGroupId(),
                             pom.getArtifactId().equals(MavenProject.EMPTY_PROJECT_ARTIFACT_ID) ? module.getName() : pom.getArtifactId(),
                             pom.getVersion().equals(MavenProject.EMPTY_PROJECT_VERSION) ? module.getVersion() : pom.getVersion()
@@ -163,10 +172,19 @@ public class MavenPlugin implements Plugin<ProjectInternal> {
                 Conf2ScopeMappingContainer.COMPILE);
         mavenScopeMappings.addMapping(RUNTIME_PRIORITY, configurations.getByName(JavaPlugin.RUNTIME_CONFIGURATION_NAME),
                 Conf2ScopeMappingContainer.RUNTIME);
+        mavenScopeMappings.addMapping(RUNTIME_PRIORITY, configurations.getByName(JavaPlugin.IMPLEMENTATION_CONFIGURATION_NAME),
+                Conf2ScopeMappingContainer.RUNTIME);
         mavenScopeMappings.addMapping(TEST_COMPILE_PRIORITY, configurations.getByName(JavaPlugin.TEST_COMPILE_CONFIGURATION_NAME),
                 Conf2ScopeMappingContainer.TEST);
         mavenScopeMappings.addMapping(TEST_RUNTIME_PRIORITY, configurations.getByName(JavaPlugin.TEST_RUNTIME_CONFIGURATION_NAME),
                 Conf2ScopeMappingContainer.TEST);
+        mavenScopeMappings.addMapping(TEST_RUNTIME_PRIORITY, configurations.getByName(JavaPlugin.TEST_IMPLEMENTATION_CONFIGURATION_NAME),
+                Conf2ScopeMappingContainer.TEST);
+    }
+
+    private void configureJavaLibraryScopeMappings(ConfigurationContainer configurations, Conf2ScopeMappingContainer mavenScopeMappings) {
+        mavenScopeMappings.addMapping(COMPILE_PRIORITY, configurations.getByName(JavaPlugin.API_CONFIGURATION_NAME),
+                Conf2ScopeMappingContainer.COMPILE);
     }
 
     private void configureWarScopeMappings(ConfigurationContainer configurations, Conf2ScopeMappingContainer mavenScopeMappings) {
