@@ -126,9 +126,9 @@ public class NativeComponentModelPlugin implements Plugin<ProjectInternal> {
     public void apply(final ProjectInternal project) {
         project.getPluginManager().apply(ComponentModelBasePlugin.class);
 
-        project.getExtensions().create("buildTypes", DefaultBuildTypeContainer.class, instantiator);
-        project.getExtensions().create("flavors", DefaultFlavorContainer.class, instantiator);
-        project.getExtensions().create("toolChains", DefaultNativeToolChainRegistry.class, instantiator);
+        project.getExtensions().create(BuildTypeContainer.class, "buildTypes", DefaultBuildTypeContainer.class, instantiator);
+        project.getExtensions().create(FlavorContainer.class, "flavors", DefaultFlavorContainer.class, instantiator);
+        project.getExtensions().create(NativeToolChainRegistryInternal.class, "toolChains", DefaultNativeToolChainRegistry.class, instantiator);
     }
 
     static class Rules extends RuleSource {
@@ -323,7 +323,7 @@ public class NativeComponentModelPlugin implements Plugin<ProjectInternal> {
                     linkTask.setTargetPlatform(binary.getTargetPlatform());
                     linkTask.setOutputFile(binary.getSharedLibraryFile());
                     linkTask.setInstallName(binary.getSharedLibraryFile().getName());
-                    linkTask.setLinkerArgs(binary.getLinker().getArgs());
+                    linkTask.getLinkerArgs().set(binary.getLinker().getArgs());
 
                     linkTask.lib(new NativeComponents.BinaryLibs(binary) {
                         @Override
