@@ -63,7 +63,7 @@ public class WorkerDaemonClientsManager implements Stoppable {
     }
 
     // TODO - should supply and check for the same parameters as passed to reserveNewClient()
-    public <T extends WorkSpec> WorkerDaemonClient<T> reserveIdleClient(DaemonForkOptions forkOptions) {
+    public WorkerDaemonClient reserveIdleClient(DaemonForkOptions forkOptions) {
         return reserveIdleClient(forkOptions, idleClients);
     }
 
@@ -87,7 +87,7 @@ public class WorkerDaemonClientsManager implements Stoppable {
         }
     }
 
-    public <T extends WorkSpec> WorkerDaemonClient<T> reserveNewClient(Class<? extends WorkerProtocol<T>> workerProtocolImplementationClass, DaemonForkOptions forkOptions) {
+    public WorkerDaemonClient reserveNewClient(Class<? extends WorkerProtocol<ActionExecutionSpec>> workerProtocolImplementationClass, DaemonForkOptions forkOptions) {
         //allow the daemon to be started concurrently
         WorkerDaemonClient client = workerDaemonStarter.startDaemon(workerProtocolImplementationClass, forkOptions);
         synchronized (lock) {
